searchData={"items":[{"type":"behaviour","doc":"Prompts provide LLMs with autogenerated user/assistant prompts.\n\nYou can implement a prompt as follows:\n\n    defmodule MyApp.Prompts.CodeReview do\n      use Vancouver.Prompt\n\n      def name, do: \"code_review\"\n      def description, do: \"Asks the LLM to analyze code quality and suggest improvements\"\n\n      def arguments do\n        [\n          %{\n            \"name\" => \"code\",\n            \"description\" => \"The code to review\",\n            \"required\" => true\n          }\n        ]\n      end\n\n      def run(conn, %{\"code\" => code}) do\n        send_text(conn, \"Please review this code: #{code}\")\n      end\n    end","title":"Vancouver.Prompt","ref":"Vancouver.Prompt.html"},{"type":"behaviour","doc":"Prompts provide helper functions to send valid MCP responses:\n\n- `send_audio/4` - sends an audio response\n- `send_image/4` - sends an image response\n- `send_text/3` - sends a text response","title":"Sending responses - Vancouver.Prompt","ref":"Vancouver.Prompt.html#module-sending-responses"},{"type":"callback","doc":"Schema defining the prompt's arguments.","title":"Vancouver.Prompt.arguments/0","ref":"Vancouver.Prompt.html#c:arguments/0"},{"type":"callback","doc":"Human readable description of what the prompt does.","title":"Vancouver.Prompt.description/0","ref":"Vancouver.Prompt.html#c:description/0"},{"type":"callback","doc":"Unique identifier for the prompt.","title":"Vancouver.Prompt.name/0","ref":"Vancouver.Prompt.html#c:name/0"},{"type":"type","doc":"","title":"Vancouver.Prompt.role/0","ref":"Vancouver.Prompt.html#t:role/0"},{"type":"callback","doc":"Execute the prompt with the given arguments.","title":"Vancouver.Prompt.run/2","ref":"Vancouver.Prompt.html#c:run/2"},{"type":"function","doc":"Sends audio response.\n\nAccepts a `:role` option, which can be either `:user` or `:assistant`, defaulting to `:user`.","title":"Vancouver.Prompt.send_audio/4","ref":"Vancouver.Prompt.html#send_audio/4"},{"type":"function","doc":"iex> send_audio(conn, \"base64-encoded-audio-data\", \"audio/wav\")\n\n    iex> send_audio(conn, \"base64-encoded-audio-data\", \"audio/wav\", role: :user)\n\n    iex> send_audio(conn, \"base64-encoded-audio-data\", \"audio/wav\", role: :assistant)","title":"Examples - Vancouver.Prompt.send_audio/4","ref":"Vancouver.Prompt.html#send_audio/4-examples"},{"type":"function","doc":"Sends image response.\n\nAccepts a `:role` option, which can be either `:user` or `:assistant`, defaulting to `:user`.","title":"Vancouver.Prompt.send_image/4","ref":"Vancouver.Prompt.html#send_image/4"},{"type":"function","doc":"iex> send_image(conn, \"base64-encoded-data\", \"image/png\")\n\n    iex> send_image(conn, \"base64-encoded-data\", \"image/png\", role: :user)\n\n    iex> send_image(conn, \"base64-encoded-data\", \"image/png\", role: :assistant)","title":"Examples - Vancouver.Prompt.send_image/4","ref":"Vancouver.Prompt.html#send_image/4-examples"},{"type":"function","doc":"Sends text response.\n\nAccepts a `:role` option, which can be either `:user` or `:assistant`, defaulting to `:user`.","title":"Vancouver.Prompt.send_text/3","ref":"Vancouver.Prompt.html#send_text/3"},{"type":"function","doc":"iex> send_text(conn, \"hello\")\n\n    iex> send_text(conn, \"hello\", role: :user)\n\n    iex> send_text(conn, \"hello\", role: :assistant)","title":"Examples - Vancouver.Prompt.send_text/3","ref":"Vancouver.Prompt.html#send_text/3-examples"},{"type":"module","doc":"Conveniences for testing Vancouver prompts.","title":"Vancouver.PromptTest","ref":"Vancouver.PromptTest.html"},{"type":"function","doc":"Asserts that the response was successful, and that audio content was returned.","title":"Vancouver.PromptTest.audio_response/1","ref":"Vancouver.PromptTest.html#audio_response/1"},{"type":"function","doc":"content = audio_response(conn)\n    assert content[\"data\"] == \"base64-audio-data\"\n    assert content[\"mimeType\"] == \"audio/wav\"","title":"Examples - Vancouver.PromptTest.audio_response/1","ref":"Vancouver.PromptTest.html#audio_response/1-examples"},{"type":"function","doc":"Creates a valid request body for a prompt get request.","title":"Vancouver.PromptTest.build_get_request/2","ref":"Vancouver.PromptTest.html#build_get_request/2"},{"type":"function","doc":"body = build_get_request(\"code_review\", %{\"code\" => \"def hello, do: \"Hello, World!\"\"})","title":"Examples - Vancouver.PromptTest.build_get_request/2","ref":"Vancouver.PromptTest.html#build_get_request/2-examples"},{"type":"function","doc":"Gets the role of the prompt.","title":"Vancouver.PromptTest.get_role/1","ref":"Vancouver.PromptTest.html#get_role/1"},{"type":"function","doc":"assert get_role(conn) == \"user\"\n\n    assert get_role(conn) == \"assistant\"","title":"Examples - Vancouver.PromptTest.get_role/1","ref":"Vancouver.PromptTest.html#get_role/1-examples"},{"type":"function","doc":"Asserts that the response was successful, and that image content was returned.","title":"Vancouver.PromptTest.image_response/1","ref":"Vancouver.PromptTest.html#image_response/1"},{"type":"function","doc":"content = image_response(conn)\n    assert content[\"data\"] == \"base64-image-data\"\n    assert content[\"mimeType\"] == \"image/png\"","title":"Examples - Vancouver.PromptTest.image_response/1","ref":"Vancouver.PromptTest.html#image_response/1-examples"},{"type":"function","doc":"Asserts that the response was successful, and that text content was returned.","title":"Vancouver.PromptTest.text_response/1","ref":"Vancouver.PromptTest.html#text_response/1"},{"type":"function","doc":"assert text_response(conn) == \"Hello, world!\"","title":"Examples - Vancouver.PromptTest.text_response/1","ref":"Vancouver.PromptTest.html#text_response/1-examples"},{"type":"behaviour","doc":"Tools enable LLMs to perform actions.\n\nYou can implement a tool as follows:\n\n    defmodule MyApp.Tools.CalculateSum do\n      use Vancouver.Tool\n\n      def name, do: \"calculate_sum\"\n      def description, do: \"Add two numbers together\"\n\n      def input_schema do\n        %{\n          \"type\" => \"object\",\n          \"properties\" => %{\n            \"a\" => %{\"type\" => \"number\"},\n            \"b\" => %{\"type\" => \"number\"}\n          },\n          \"required\" => [\"a\", \"b\"]\n        }\n      end\n\n      def run(conn, %{\"a\" => a, \"b\" => b}) do\n        send_text(conn, \"#{a + b}\")\n      end\n    end\n\nThe input schema must be a valid [JSON Schema](https://json-schema.org) object.","title":"Vancouver.Tool","ref":"Vancouver.Tool.html"},{"type":"behaviour","doc":"Tools provide helper functions to send valid MCP responses:\n\n- `send_json/2` - sends a JSON response\n- `send_audio/3` - sends an audio response\n- `send_image/3` - sends an image response\n- `send_text/2` - sends a text response\n- `send_error/2` - sends an error response","title":"Sending responses - Vancouver.Tool","ref":"Vancouver.Tool.html#module-sending-responses"},{"type":"callback","doc":"Human readable description of what the tool does.","title":"Vancouver.Tool.description/0","ref":"Vancouver.Tool.html#c:description/0"},{"type":"callback","doc":"JSON Schema defining the tool's input parameters.","title":"Vancouver.Tool.input_schema/0","ref":"Vancouver.Tool.html#c:input_schema/0"},{"type":"callback","doc":"Unique identifier for the tool.","title":"Vancouver.Tool.name/0","ref":"Vancouver.Tool.html#c:name/0"},{"type":"callback","doc":"Execute the tool with the given parameters.","title":"Vancouver.Tool.run/2","ref":"Vancouver.Tool.html#c:run/2"},{"type":"function","doc":"Sends audio response.","title":"Vancouver.Tool.send_audio/3","ref":"Vancouver.Tool.html#send_audio/3"},{"type":"function","doc":"iex> send_audio(conn, \"base64-encoded-audio-data\", \"audio/wav\")","title":"Examples - Vancouver.Tool.send_audio/3","ref":"Vancouver.Tool.html#send_audio/3-examples"},{"type":"function","doc":"Sends an error response.","title":"Vancouver.Tool.send_error/2","ref":"Vancouver.Tool.html#send_error/2"},{"type":"function","doc":"iex> send_error(conn, \"an error occurred\")","title":"Examples - Vancouver.Tool.send_error/2","ref":"Vancouver.Tool.html#send_error/2-examples"},{"type":"function","doc":"Sends image response.","title":"Vancouver.Tool.send_image/3","ref":"Vancouver.Tool.html#send_image/3"},{"type":"function","doc":"iex> send_image(conn, \"base64-encoded-data\", \"image/png\")","title":"Examples - Vancouver.Tool.send_image/3","ref":"Vancouver.Tool.html#send_image/3-examples"},{"type":"function","doc":"Sends JSON response.","title":"Vancouver.Tool.send_json/2","ref":"Vancouver.Tool.html#send_json/2"},{"type":"function","doc":"iex> send_json(conn, %{id: 123})","title":"Examples - Vancouver.Tool.send_json/2","ref":"Vancouver.Tool.html#send_json/2-examples"},{"type":"function","doc":"Sends text response.","title":"Vancouver.Tool.send_text/2","ref":"Vancouver.Tool.html#send_text/2"},{"type":"function","doc":"iex> send_text(conn, \"hello\")","title":"Examples - Vancouver.Tool.send_text/2","ref":"Vancouver.Tool.html#send_text/2-examples"},{"type":"module","doc":"Conveniences for testing Vancouver tools.","title":"Vancouver.ToolTest","ref":"Vancouver.ToolTest.html"},{"type":"function","doc":"Asserts that the response was successful, and that audio content was returned.","title":"Vancouver.ToolTest.audio_response/1","ref":"Vancouver.ToolTest.html#audio_response/1"},{"type":"function","doc":"content = audio_response(conn)\n    assert content[\"data\"] == \"base64-audio-data\"\n    assert content[\"mimeType\"] == \"audio/wav\"","title":"Examples - Vancouver.ToolTest.audio_response/1","ref":"Vancouver.ToolTest.html#audio_response/1-examples"},{"type":"function","doc":"Creates a valid request body for a tool call request.","title":"Vancouver.ToolTest.build_call_request/2","ref":"Vancouver.ToolTest.html#build_call_request/2"},{"type":"function","doc":"body = build_call_request(\"calculate_sum\", %{\"a\" => 1, \"b\" => 2})","title":"Examples - Vancouver.ToolTest.build_call_request/2","ref":"Vancouver.ToolTest.html#build_call_request/2-examples"},{"type":"function","doc":"Asserts that the response was an error, and returns the error text.","title":"Vancouver.ToolTest.error_response/1","ref":"Vancouver.ToolTest.html#error_response/1"},{"type":"function","doc":"assert error_response(conn) == \"An error occurred\"","title":"Examples - Vancouver.ToolTest.error_response/1","ref":"Vancouver.ToolTest.html#error_response/1-examples"},{"type":"function","doc":"Asserts that the response was successful, and that image content was returned.","title":"Vancouver.ToolTest.image_response/1","ref":"Vancouver.ToolTest.html#image_response/1"},{"type":"function","doc":"content = image_response(conn)\n    assert content[\"data\"] == \"base64-image-data\"\n    assert content[\"mimeType\"] == \"image/png\"","title":"Examples - Vancouver.ToolTest.image_response/1","ref":"Vancouver.ToolTest.html#image_response/1-examples"},{"type":"function","doc":"Asserts that the response was successful, and that JSON content was returned.","title":"Vancouver.ToolTest.json_response/1","ref":"Vancouver.ToolTest.html#json_response/1"},{"type":"function","doc":"assert json_response(conn) == %{\"key\" => \"value\"}","title":"Examples - Vancouver.ToolTest.json_response/1","ref":"Vancouver.ToolTest.html#json_response/1-examples"},{"type":"function","doc":"Asserts that the response was successful, and that text content was returned.","title":"Vancouver.ToolTest.text_response/1","ref":"Vancouver.ToolTest.html#text_response/1"},{"type":"function","doc":"assert text_response(conn) == \"Hello, world!\"","title":"Examples - Vancouver.ToolTest.text_response/1","ref":"Vancouver.ToolTest.html#text_response/1-examples"},{"type":"extras","doc":"[![CI](https://github.com/jameslong/vancouver/actions/workflows/test.yml/badge.svg)](https://github.com/jameslong/vancouver/actions/workflows/test.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/vancouver.svg)](https://hex.pm/packages/vancouver)\n[![Hexdocs.pm](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/vancouver/)\n[![Hex.pm](https://img.shields.io/hexpm/dt/vancouver.svg)](https://hex.pm/packages/vancouver)\n[![Hex.pm](https://img.shields.io/hexpm/dw/vancouver.svg)](https://hex.pm/packages/vancouver)\n\n# Vancouver\n\nVancouver makes it easy to add [Model Context Protocol (MCP)](https://modelcontextprotocol.io/introduction) functionality to your Phoenix/Bandit server. Vancouver handles initialization, request validation, and offers helper functions to simplify the creation of MCP tools and prompts.","title":"README","ref":"readme.html"},{"type":"extras","doc":"","title":"Getting started - README","ref":"readme.html#getting-started"},{"type":"extras","doc":"In `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:vancouver, \"~> 0.3\"}\n  ]\nend\n```","title":"1. Add dependency - README","ref":"readme.html#1-add-dependency"},{"type":"extras","doc":"You can implement tools like this:\n\n```elixir\ndefmodule MyApp.Tools.CalculateSum do\n  use Vancouver.Tool\n\n  def name, do: \"calculate_sum\"\n  def description, do: \"Add two numbers together\"\n\n  def input_schema do\n    %{\n      \"type\" => \"object\",\n      \"properties\" => %{\n        \"a\" => %{\"type\" => \"number\"},\n        \"b\" => %{\"type\" => \"number\"}\n      },\n      \"required\" => [\"a\", \"b\"]\n    }\n  end\n\n  def run(conn, %{\"a\" => a, \"b\" => b}) do\n    send_text(conn, \"#{a + b}\")\n  end\nend\n```\n\nAnd prompts like this:\n\n```elixir\ndefmodule MyApp.Prompts.CodeReview do\n  use Vancouver.Prompt\n\n  def name, do: \"code_review\"\n  def description, do: \"Asks the LLM to analyze code quality and suggest improvements\"\n\n  def arguments do\n    [\n      %{\n        \"name\" => \"code\",\n        \"description\" => \"The code to review\",\n        \"required\" => true\n      }\n    ]\n  end\n\n  def run(conn, %{\"code\" => code}) do\n    send_text(conn, \"Please review this code: #{code}\")\n  end\nend\n```","title":"2. Create your tools/prompts - README","ref":"readme.html#2-create-your-tools-prompts"},{"type":"extras","doc":"In `config.ex`:\n\n```elixir\nconfig :vancouver,\n  name: \"My MCP Server\",\n  version: \"1.0.0\"\n```","title":"3. Add config - README","ref":"readme.html#3-add-config"},{"type":"extras","doc":"In `router.ex`:\n\n```elixir\nforward \"/mcp\", Vancouver.Router, \n  tools: [MyApp.Tools.CalculateSum],\n  prompts: [MyApp.Prompts.CodeReview]\n```","title":"4. Add your MCP route - README","ref":"readme.html#4-add-your-mcp-route"},{"type":"extras","doc":"E.g. For Claude Desktop, you can modify your config `Settings -> Developer -> Edit config` as follows:\n\n    {\n        \"mcpServers\": {\n            \"MyApp\": {\n                \"command\": \"npx\",\n                \"args\": [\n                    \"mcp-remote\",\n                    \"http://localhost:4000/mcp\"\n                ]\n            }\n        }\n    }\n\nRun your server, and restart Claude to starting using your MCP tools. 🚀","title":"5. (Optional) Add to your MCP client - README","ref":"readme.html#5-optional-add-to-your-mcp-client"},{"type":"extras","doc":"","title":"FAQ - README","ref":"readme.html#faq"},{"type":"extras","doc":"Not yet. Vancouver currently supports:\n\n- tools\n- prompts\n- sync responses (no streaming)\n\nHowever, the library is simple enough that you should be able to modify it for your needs.\n\nFor more info on the protocol itself, see the [MCP User Guide](https://modelcontextprotocol.io/introduction).","title":"Does Vancouver support all parts of the Model Context Protocol specification? - README","ref":"readme.html#does-vancouver-support-all-parts-of-the-model-context-protocol-specification"},{"type":"extras","doc":"No. This library is in early development. Expect breaking changes.","title":"Is Vancouver stable / ready for production? - README","ref":"readme.html#is-vancouver-stable-ready-for-production"},{"type":"extras","doc":"Vancouver is the natural home of MCP (Mountain, Coffee, and Phoenix).","title":"Why is this library called Vancouver? - README","ref":"readme.html#why-is-this-library-called-vancouver"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}